Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EventFromAzure ¶
func EventFromAzure(alert AzureAlert) *events.Event
EventFromAzure converts alerts sent from azure into cloud events
func EventFromIcinga ¶
func EventFromIcinga(alert IcingaAlert) *events.Event
EventFromIcinga converts alerts sent from icinga into cloud events
func EventFromSite247 ¶
func EventFromSite247(alert Site247Alert) *events.Event
EventFromSite247 converts alerts sent from site24x7 into cloud events
Types ¶
type AzureActivity ¶
type AzureActivity struct {
Channels string `json:"channels"`
CorrelationID string `json:"correlationId"`
EventSource string `json:"eventSource"`
EventTimestamp string `json:"eventTimestamp"`
EventDataID string `json:"eventDataId"`
Level string `json:"level"`
OperationName string `json:"operationName"`
OperationID string `json:"operationId"`
Properties AzureActivityProperty `json:"properties"`
ResourceID string `json:"resourceId"`
ResourceGroupName string `json:"resourceGroupName"`
ResourceProviderName string `json:"resourceProviderName"`
Status string `json:"status"`
SubscriptionID string `json:"subscriptionId"`
SubmissionTimestamp string `json:"submissionTimestamp"`
ResourceType string `json:"resourceType"`
}
type AzureActivityProperty ¶
type AzureAlert ¶
type AzureContext ¶
type AzureContext struct {
Activity AzureActivity `json:"activityLog"`
}
type AzureData ¶
type AzureData struct {
Status string `json:"activated"`
Context AzureContext `json:"context"`
}
type IcingaAlert ¶
type IcingaAlert struct {
NotificationType string `json:"notification_type"`
ServiceDescription string `json:"service_description"`
HostAlias string `json:"host_alias"`
HostAddress string `json:"host_address"`
ServiceState string `json:"service_state"`
LongDateTime string `json:"long_date_time"`
ServiceOutput string `json:"service_output"`
NotificationAuthorName string `json:"notification_author_name"`
NotificationComment string `json:"notification_comment"`
HostDisplayName string `json:"host_display_name"`
ServiceDisplayName string `json:"service_display_name"`
}
IcingaAlert structure for Icinga alert
type Site247Alert ¶
type Site247Alert struct {
MonitorName string `json:"MONITORNAME,omitempty"`
MonitorGroupName string `json:"MONITOR_GROUPNAME,omitempty"`
SearchPollFrequency int `json:"SEARCH POLLFREQUENCY,omitempty"`
MonitorID int `json:"MONITOR_ID,omitempty"`
FailedLocations string `json:"FAILED_LOCATIONS,omitempty"`
MonitorURL string `json:"MONITORURL,omitempty"`
IncidentTimeISO string `json:"INCIDENT_TIME_ISO,omitempty"`
MonitorType string `json:"MONITORTYPE,omitempty"`
Status string `json:"STATUS,omitempty"`
Timezone string `json:"TIMEZONE,omitempty"`
IncidentTime string `json:"INCIDENT_TIME,omitempty"`
IncidentReason string `json:"INCIDENT_REASON,omitempty"`
OutageTimeUnixFormat string `json:"OUTAGE_TIME_UNIX_FORMAT,omitempty"`
RCALink string `json:"RCA_LINK,omitempty"`
Tags []map[string]interface{} `json:"JSON_TAGS,omitempty"`
}
Site247Alert structure for site24x7 alert
Click to show internal directories.
Click to hide internal directories.